# open_petro_elastic
Library used for Petro elastic modelling.

## Installation
```
pip install .
```

## Usage
```
open_petro_elastic -h
```

see [docs](docs/index.rst) for more usage instructions.

## Run tests
```
pytest
```
